@@ -1,22 +1,27 @@
-#!/usr/bin/r -t
+#!/usr/bin/env r 
 #
-# a simple example to update packages in /usr/local/lib/R/site-library
-# parameters are easily adjustable
+# A simple example to update packages in /usr/local/lib/R/site-library
+# Parameters are easily adjustable
+#
+# Copyright (C) 2006 - 2014  Dirk Eddelbuettel
+#
+# Released under GPL (>= 2)
 
 ## adjust as necessary, see help('download.packages')
-repos <- "http://cran.r-project.org"
+repos <- "http://cran.rstudio.com" 
+
 ## or use BioC's repo list if Biobase is installed:
-suppressMessages(rc <- require(Biobase))
-if (rc) {
-  repos <- Biobase:::biocReposList()
-}
+#suppressMessages(rc <- require(Biobase))
+#if (rc) {
+#  repos <- Biobase:::biocReposList()
+#}
 
 ## this makes sense on Debian where no package touch /usr/local
 lib.loc <- "/usr/local/lib/R/site-library"
 
 ## simply unrolling of all unlink over all files 'repos*' in $TMP
 clearCache <- function() {
-  sapply(list.files(path=tempdir(), pattern="libloc*", full.names=TRUE), unlink)
+  sapply(list.files(path=tempdir(), pattern="*rds$", full.names=TRUE), unlink)
 }
 
 ## Always clear caches of remote and local packages
